@@ -16,10 +16,6 @@
 * limitations under the License.
 */
 
-#ifndef NDEBUG
-//#define PRINT_DEBUG
-#endif
-
 #include "DMDetector.h"
 #include "BitMatrix.h"
 #include "BitMatrixCursor.h"
@@ -29,10 +25,7 @@
 #include "Point.h"
 #include "WhiteRectDetector.h"
 
-#ifdef PRINT_DEBUG
-#include "BitMatrixIO.h"
 #include "LogMatrix.h"
-#endif
 
 #include <algorithm>
 #include <array>
@@ -45,13 +38,6 @@
 #include <vector>
 
 namespace ZXing {
-
-#ifdef PRINT_DEBUG
-static LogMatrix log;
-#else
-template<typename T> void log(PointT<T>, int = 0) {}
-#endif
-
 namespace DataMatrix {
 
 /**
@@ -122,9 +108,10 @@ inline static bool IsValidPoint(const ResultPoint& p, int imgWidth, int imgHeigh
 	return p.x() >= 0 && p.x() < imgWidth && p.y() > 0 && p.y() < imgHeight;
 }
 
-inline static float RoundToNearest(float x)
+template <typename T>
+inline static float RoundToNearestF(T x)
 {
-	return std::round(x);
+	return static_cast<float>(std::round(x));
 }
 
 /**
@@ -136,15 +123,15 @@ static bool CorrectTopRightRectangular(const BitMatrix& image, const ResultPoint
 									   const ResultPoint& topRight, int dimensionTop, int dimensionRight,
 									   ResultPoint& result)
 {
-	float corr = RoundToNearest(distance(bottomLeft, bottomRight)) / static_cast<float>(dimensionTop);
-	float norm = RoundToNearest(distance(topLeft, topRight));
+	float corr = RoundToNearestF(distance(bottomLeft, bottomRight)) / static_cast<float>(dimensionTop);
+	float norm = RoundToNearestF(distance(topLeft, topRight));
 	float cos = (topRight.x() - topLeft.x()) / norm;
 	float sin = (topRight.y() - topLeft.y()) / norm;
 
 	ResultPoint c1(topRight.x() + corr*cos, topRight.y() + corr*sin);
 
-	corr = RoundToNearest(distance(bottomLeft, topLeft)) / (float)dimensionRight;
-	norm = RoundToNearest(distance(bottomRight, topRight));
+	corr = RoundToNearestF(distance(bottomLeft, topLeft)) / (float)dimensionRight;
+	norm = RoundToNearestF(distance(bottomRight, topRight));
 	cos = (topRight.x() - bottomRight.x()) / norm;
 	sin = (topRight.y() - bottomRight.y()) / norm;
 
@@ -178,15 +165,15 @@ static bool CorrectTopRightRectangular(const BitMatrix& image, const ResultPoint
 static ResultPoint CorrectTopRight(const BitMatrix& image, const ResultPoint& bottomLeft, const ResultPoint& bottomRight,
                                    const ResultPoint& topLeft, const ResultPoint& topRight, int dimension)
 {
-	float corr = RoundToNearest(distance(bottomLeft, bottomRight)) / (float)dimension;
-	float norm = RoundToNearest(distance(topLeft, topRight));
+	float corr = RoundToNearestF(distance(bottomLeft, bottomRight)) / (float)dimension;
+	float norm = RoundToNearestF(distance(topLeft, topRight));
 	float cos = (topRight.x() - topLeft.x()) / norm;
 	float sin = (topRight.y() - topLeft.y()) / norm;
 
 	ResultPoint c1(topRight.x() + corr * cos, topRight.y() + corr * sin);
 
-	corr = RoundToNearest(distance(bottomLeft, topLeft)) / (float)dimension;
-	norm = RoundToNearest(distance(bottomRight, topRight));
+	corr = RoundToNearestF(distance(bottomLeft, topLeft)) / (float)dimension;
+	norm = RoundToNearestF(distance(bottomRight, topRight));
 	cos = (topRight.x() - bottomRight.x()) / norm;
 	sin = (topRight.y() - bottomRight.y()) / norm;
 
@@ -231,9 +218,9 @@ static float CrossProductZ(const ResultPoint& a, const ResultPoint& b, const Res
 static void OrderByBestPatterns(const ResultPoint*& p0, const ResultPoint*& p1, const ResultPoint*& p2)
 {
 	// Find distances between pattern centers
-	float zeroOneDistance = distance(*p0, *p1);
-	float oneTwoDistance = distance(*p1, *p2);
-	float zeroTwoDistance = distance(*p0, *p2);
+	auto zeroOneDistance = distance(*p0, *p1);
+	auto oneTwoDistance = distance(*p1, *p2);
+	auto zeroTwoDistance = distance(*p0, *p2);
 
 	const ResultPoint* pointA;
 	const ResultPoint* pointB;
@@ -491,23 +478,23 @@ public:
 
 	void setDirectionInward(PointF d) { _directionInward = normalized(d); }
 
-	bool evaluate(double maxDist = -1)
+	bool evaluate(double maxSignedDist = -1)
 	{
-		auto ps = _points;
-		bool ret = evaluate(ps);
-		if (maxDist > 0) {
-			size_t old_points_size;
+		bool ret = evaluate(_points);
+		if (maxSignedDist > 0) {
+			auto points = _points;
 			while (true) {
-				old_points_size = _points.size();
-				_points.erase(std::remove_if(_points.begin(), _points.end(),
-											 [this, maxDist](auto p) { return this->signedDistance(p) > maxDist; }),
-							  _points.end());
-				if (old_points_size == _points.size())
+				auto old_points_size = points.size();
+				points.erase(
+					std::remove_if(points.begin(), points.end(),
+								   [this, maxSignedDist](auto p) { return this->signedDistance(p) > maxSignedDist; }),
+					points.end());
+				if (old_points_size == points.size())
 					break;
 #ifdef PRINT_DEBUG
-				printf("removed %zu points\n", old_points_size - _points.size());
+				printf("removed %zu points\n", old_points_size - points.size());
 #endif
-				ret = evaluate(_points);
+				ret = evaluate(points);
 			}
 		}
 		return ret;
@@ -685,7 +672,7 @@ public:
 							return true;
 						}
 					}
-				} else if (gaps == 0 && line.points().size() >= 2u * maxStepSize)
+				} else if (gaps == 0 && line.points().size() >= static_cast<size_t>(2 * maxStepSize))
 					return false; // no point in following a line that has no gaps
 			}
 
@@ -747,8 +734,8 @@ static DetectorResult DetectNew(const BitMatrix& image, bool tryRotate)
 		while (startTracer.step()) {
 			log(startTracer.p);
 
-			// go forward until we reach a white/black border
-			if (!startTracer.isEdgeBehind())
+			// continue until we cross from black into white
+			if (!startTracer.edgeAtBack().isWhite())
 				continue;
 
 #ifdef PRINT_DEBUG
@@ -765,7 +752,7 @@ static DetectorResult DetectNew(const BitMatrix& image, bool tryRotate)
 			auto t = startTracer;
 
 			// follow left leg upwards
-			t.setDirection(t.right());
+			t.turnRight();
 			if (!t.traceLine(t.right(), lineL))
 				continue;
 
@@ -874,9 +861,6 @@ static DetectorResult DetectNew(const BitMatrix& image, bool tryRotate)
 			auto res = SampleGrid(image, tl, bl, br, tr, dimT, dimR);
 
 #ifdef PRINT_DEBUG
-			printf("modules top: %d, right: %d\n", dimT, dimR);
-			printf("%s", ToString(res.bits()).c_str());
-
 			for (RegressionLine* l : {&lineL, &lineB, &lineT, &lineR})
 				log(l->points());
 #endif
