@@ -15,8 +15,8 @@
 * limitations under the License.
 */
 
-#include "pdf417/PDFDecodedBitStreamParser.h"
-#include "pdf417/PDFDecoderResultExtra.h"
+#include "PDFDecodedBitStreamParser.h"
+#include "PDFDecoderResultExtra.h"
 #include "CharacterSetECI.h"
 #include "CharacterSet.h"
 #include "TextDecoder.h"
@@ -29,6 +29,7 @@
 
 #include <array>
 #include <cassert>
+#include <utility>
 
 namespace ZXing {
 namespace Pdf417 {
@@ -425,7 +426,7 @@ static int ByteCompaction(int mode, const std::vector<int>& codewords, Character
 			}
 		}
 	}
-	TextDecoder::Append(result, decodedBytes.data(), decodedBytes.length(), encoding);
+	TextDecoder::Append(result, decodedBytes.data(), Size(decodedBytes), encoding);
 	return codeIndex;
 }
 
